@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2003 Jacob Perkins
  * Copyright (C) 2004-2005 Stefan Walter
+ * Copyright (C) 2011 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,41 +31,32 @@
 #include <gtk/gtk.h>
 #include <time.h>
 
-#include "seahorse-context.h"
-
 #ifdef WITH_SHARING
 #include <avahi-client/client.h>
-const AvahiPoll* seahorse_util_dns_sd_get_poll ();
+const AvahiPoll* seahorse_util_dns_sd_get_poll (void);
 #endif
 
-struct _SeahorseObject;
-
-typedef enum {
-    SEAHORSE_CRYPT_SUFFIX,
-    SEAHORSE_SIG_SUFFIX,
-} SeahorseSuffix;
-
 typedef guint64 SeahorseVersion;
 
 #define SEAHORSE_EXT_ASC ".asc"
-#define SEAHORSE_EXT_SIG ".sig"
-#define SEAHORSE_EXT_PGP ".pgp"
 #define SEAHORSE_EXT_GPG ".gpg"
 
-gchar*		seahorse_util_get_date_string		    (const time_t		time);
-gchar*		seahorse_util_get_display_date_string   (const time_t		time);
+gchar*      seahorse_util_get_date_string           (const time_t time);
+gchar*      seahorse_util_get_display_date_string   (const time_t time);
 
 
-#define SEAHORSE_ERROR  (seahorse_util_error_domain ())
+#define     SEAHORSE_ERROR                      (seahorse_util_error_domain ())
 
-GQuark      seahorse_util_error_domain ();
+GQuark      seahorse_util_error_domain          (void);
 
-void        seahorse_util_show_error            (GtkWidget          *parent,
-                                                 const gchar        *heading,
-                                                 const gchar        *message);
-                                                 
-void        seahorse_util_handle_error          (GError*            err,
-                                                 const char*        desc, ...);
+void        seahorse_util_show_error            (gpointer parent,
+                                                 const gchar *heading,
+                                                 const gchar *message);
+
+void        seahorse_util_handle_error          (GError **error,
+                                                 gpointer parent,
+                                                 const gchar* description,
+                                                 ...);
 
 gboolean    seahorse_util_prompt_delete         (const gchar *text,
                                                  GtkWidget *parent);
@@ -77,11 +69,6 @@ guint       seahorse_util_read_data_block       (GString            *buf,
                                                  const gchar        *start, 
                                                  const gchar*       end);
 
-GMemoryInputStream*
-            seahorse_util_memory_input_string   (const gchar *string, gsize length);
-
-gsize       seahorse_util_memory_output_length  (GMemoryOutputStream *output);
-
 gboolean    seahorse_util_print_fd          (int fd, 
                                              const char* data);
 
@@ -94,16 +81,8 @@ gboolean    seahorse_util_uri_exists        (const gchar* uri);
 
 gchar*      seahorse_util_uri_unique        (const gchar* uri);
 
-gchar*      seahorse_util_uri_replace_ext   (const gchar *uri, 
-                                             const gchar *ext);
-
 const gchar* seahorse_util_uri_get_last     (const gchar* uri);
 
-const gchar* seahorse_util_uri_split_last   (gchar* uri);
-
-gboolean    seahorse_util_uris_package      (const gchar* package, 
-                                             const gchar** uris);
-
 GQuark      seahorse_util_detect_mime_type   (const gchar *mime);
 
 GQuark      seahorse_util_detect_data_type   (const gchar *data,
@@ -129,42 +108,20 @@ void        seahorse_util_chooser_set_filename_full     (GtkDialog *dialog,
                                                          GList *objects);
 
 void        seahorse_util_chooser_set_filename          (GtkDialog *dialog, 
-                                                         struct _SeahorseObject *object);
+                                                         GObject *object);
 
 gchar*      seahorse_util_chooser_open_prompt           (GtkDialog *dialog);
 
 gchar*      seahorse_util_chooser_save_prompt           (GtkDialog *dialog);
 
-gboolean	seahorse_util_check_suffix		(const gchar		*path,
-                                             SeahorseSuffix     suffix);
+GList *     seahorse_util_objects_sort_by_place         (GList *objects);
 
-gchar*		seahorse_util_add_suffix		(const gchar        *path,
-                                             SeahorseSuffix     suffix,
-                                             const gchar        *prompt);
-
-gchar*      seahorse_util_remove_suffix     (const gchar        *path,
-                                             const gchar        *prompt);
-
-gchar**     seahorse_util_strvec_dup        (const gchar        **vec);
-
-guint       seahorse_util_strvec_length       (const gchar      **vec);
-
-GList*       seahorse_util_objects_sort       (GList *objects);
-
-GList*       seahorse_util_objects_splice     (GList *objects);
+GList *     seahorse_util_objects_splice_by_place       (GList *objects);
 
 gboolean    seahorse_util_string_equals       (const gchar *s1, const gchar *s2);
 
-gchar*      seahorse_util_string_up_first     (const gchar *orig);
-
 void        seahorse_util_string_lower        (gchar *s);
 
-GSList*     seahorse_util_string_slist_free   (GSList *slist);
-
-GSList*     seahorse_util_string_slist_copy   (GSList *slist);
-
-gboolean    seahorse_util_string_slist_equal  (GSList *sl1, GSList *sl2);
-
 gboolean    seahorse_util_string_is_whitespace (const gchar *text);
 
 void        seahorse_util_string_trim_whitespace (gchar *text);
@@ -189,10 +146,4 @@ SeahorseVersion seahorse_util_parse_version   (const char *version);
         g_thread_yield ();                                \
     }
 
-#ifdef _DEBUG
-#define DBG_PRINT(x) g_printerr x
-#else
-#define DBG_PRINT(x)
-#endif
-
 #endif /* __SEAHORSE_UTIL_H__ */
