@@ -31,7 +31,7 @@
 #include <glib/gi18n.h>
 
 #include "seahorse-bind.h"
-#include "seahorse-gtkstock.h"
+#include "seahorse-icons.h"
 #include "seahorse-object.h"
 #include "seahorse-object-model.h"
 #include "seahorse-object-widget.h"
@@ -40,6 +40,7 @@
 #include "seahorse-gpgme-dialogs.h"
 #include "seahorse-gpgme-key.h"
 #include "seahorse-gpgme-key-op.h"
+#include "seahorse-pgp-backend.h"
 #include "seahorse-gpg-op.h"
 #include "seahorse-pgp-dialogs.h"
 #include "seahorse-pgp-key.h"
@@ -152,14 +153,16 @@ show_gtkbuilder_widget (SeahorseWidget *swidget, const gchar *name, gboolean sho
 }
 
 static void
-set_gtkbuilder_image (SeahorseWidget *swidget, const gchar *name, const gchar *stock)
+set_gtkbuilder_image (SeahorseWidget *swidget,
+                      const gchar *name,
+                      const gchar *icon_name)
 {
     GtkWidget *widget = GTK_WIDGET (gtk_builder_get_object (swidget->gtkbuilder, name));
     
     if (!widget)
         return;
     
-    gtk_image_set_from_stock (GTK_IMAGE (widget), stock, GTK_ICON_SIZE_DIALOG);
+    gtk_image_set_from_icon_name (GTK_IMAGE (widget), icon_name, GTK_ICON_SIZE_DIALOG);
 }
 
 static void
@@ -234,7 +237,7 @@ on_pgp_signature_row_activated (GtkTreeView *treeview,
                                 gpointer user_data)
 {
 	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
-	SeahorseObject *object = NULL;
+	GObject *object = NULL;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
     
@@ -244,7 +247,7 @@ on_pgp_signature_row_activated (GtkTreeView *treeview,
 		model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
         
 	g_return_if_fail (gtk_tree_model_get_iter (model, &iter, path));
-    
+
 	object = seahorse_object_model_get_row_key (SEAHORSE_OBJECT_MODEL (model), &iter);
 	if (object != NULL && SEAHORSE_IS_PGP_KEY (object)) {
 		seahorse_pgp_key_properties_show (SEAHORSE_PGP_KEY (object), 
@@ -279,9 +282,9 @@ enum {
     UIDSIG_N_COLUMNS
 };
 
-const GType uidsig_columns[] = {
+static GType uidsig_columns[] = {
     G_TYPE_OBJECT,  /* index */
-    G_TYPE_STRING,  /* icon */
+    0 /* later */,  /* icon */
     G_TYPE_STRING,  /* name */
     G_TYPE_STRING   /* keyid */
 };
@@ -297,7 +300,7 @@ on_pgp_names_add_clicked (GtkWidget *widget,
                           gpointer user_data)
 {
 	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
-	SeahorseObject *obj = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+	GObject *obj = SEAHORSE_OBJECT_WIDGET (swidget)->object;
 	g_return_if_fail (SEAHORSE_IS_GPGME_KEY (obj));
 	seahorse_gpgme_add_uid_new (SEAHORSE_GPGME_KEY (obj), 
 	                            GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)));
@@ -408,22 +411,11 @@ static void
 names_update_row (SeahorseObjectModel *skmodel, SeahorseObject *object, 
                   GtkTreeIter *iter, SeahorseWidget *swidget)
 {
-	SeahorseObject *preferred;
-	const gchar *icon;
+	GIcon *icon;
 	const gchar *name, *id;
-    
-	/* Always use the most preferred key for this keyid */
-	preferred = seahorse_object_get_preferred (object);
-	if (preferred) {
-		while (SEAHORSE_IS_OBJECT (preferred)) {
-			object = SEAHORSE_OBJECT (preferred);
-			preferred = seahorse_object_get_preferred (preferred);
-		}
-		seahorse_object_model_set_row_object (skmodel, iter, object);
-	}
 
-	icon = seahorse_object_get_location (object) < SEAHORSE_LOCATION_LOCAL ? 
-	                 GTK_STOCK_DIALOG_QUESTION : SEAHORSE_STOCK_SIGN;
+	icon = g_themed_icon_new (SEAHORSE_IS_PGP_KEY (object) ?
+	                               SEAHORSE_ICON_SIGN : GTK_STOCK_DIALOG_QUESTION);
 	name = seahorse_object_get_markup (object);
 	id = seahorse_object_get_identifier (object);
 	
@@ -432,19 +424,21 @@ names_update_row (SeahorseObjectModel *skmodel, SeahorseObject *object,
 	                    UIDSIG_ICON, icon,
 	                    UIDSIG_NAME, name ? name : _("[Unknown]"),
 	                    UIDSIG_KEYID, id, -1);
+	g_object_unref (icon);
 }
 
 static void
 names_populate (SeahorseWidget *swidget, GtkTreeStore *store, SeahorsePgpKey *pkey)
 {
-	SeahorseObject *object;
+	GObject *object;
 	GtkTreeIter uiditer, sigiter;
-	GList *rawids = NULL;
+	GList *keyids = NULL;
 	SeahorsePgpUid *uid;
 	GList *keys, *l;
 	GList *uids, *u;
 	GList *sigs, *s;
 	GCancellable *cancellable;
+	GIcon *icon;
 
 	/* Insert all the fun-ness */
 	uids = seahorse_pgp_key_get_uids (pkey);
@@ -452,22 +446,22 @@ names_populate (SeahorseWidget *swidget, GtkTreeStore *store, SeahorsePgpKey *pk
 	for (u = uids; u; u = g_list_next (u)) {
 
 		uid = SEAHORSE_PGP_UID (u->data);
-
+		icon = g_themed_icon_new (SEAHORSE_ICON_PERSON);
 		gtk_tree_store_append (store, &uiditer, NULL);
 		gtk_tree_store_set (store, &uiditer,  
 		                    UIDSIG_OBJECT, uid,
-		                    UIDSIG_ICON, SEAHORSE_STOCK_PERSON,
+		                    UIDSIG_ICON, icon,
 		                    UIDSIG_NAME, seahorse_object_get_markup (SEAHORSE_OBJECT (uid)),
 		                    -1);
-        
-        
+		g_object_unref (icon);
+
 		/* Build a list of all the keyids */
 		sigs = seahorse_pgp_uid_get_signatures (uid);
 		for (s = sigs; s; s = g_list_next (s)) {
 			/* Never show self signatures, they're implied */
 			if (seahorse_pgp_key_has_keyid (pkey, seahorse_pgp_signature_get_keyid (s->data)))
 				continue;
-			rawids = g_list_prepend (rawids, (gpointer)seahorse_pgp_signature_get_keyid (s->data));
+			keyids = g_list_prepend (keyids, (gpointer)seahorse_pgp_signature_get_keyid (s->data));
 		}
 
 		/*
@@ -475,15 +469,14 @@ names_populate (SeahorseWidget *swidget, GtkTreeStore *store, SeahorsePgpKey *pk
 		 * ties search scope together
 		 */
 		cancellable = g_cancellable_new ();
-		keys = seahorse_context_discover_objects (seahorse_context_instance (),
-		                                          SEAHORSE_PGP, rawids, cancellable);
+		keys = seahorse_pgp_backend_discover_keys (NULL, keyids, cancellable);
 		g_object_unref (cancellable);
-		g_list_free (rawids);
-		rawids = NULL;
+		g_list_free (keyids);
+		keyids = NULL;
         
 		/* Add the keys to the store */
 		for (l = keys; l; l = g_list_next (l)) {
-			object = SEAHORSE_OBJECT (l->data);
+			object = G_OBJECT (l->data);
 			gtk_tree_store_append (store, &sigiter, &uiditer);
             
 			/* This calls the 'update-row' callback, to set the values for the key */
@@ -500,8 +493,8 @@ do_names (SeahorseWidget *swidget)
     GtkWidget *widget;
     GtkTreeStore *store;
     GtkCellRenderer *renderer;
-    
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     pkey = SEAHORSE_PGP_KEY (object);
     
     if (seahorse_object_get_usage (object) != SEAHORSE_USAGE_PRIVATE_KEY)
@@ -516,9 +509,11 @@ do_names (SeahorseWidget *swidget)
         gtk_tree_store_clear (store);
         
     } else {
-        
+	    g_assert (UIDSIG_N_COLUMNS == G_N_ELEMENTS (uidsig_columns));
+	    uidsig_columns[UIDSIG_ICON] = G_TYPE_ICON;
+
         /* This is our first time so create a store */
-        store = GTK_TREE_STORE (seahorse_object_model_new (UIDSIG_N_COLUMNS, (GType*)uidsig_columns));
+        store = GTK_TREE_STORE (seahorse_object_model_new (UIDSIG_N_COLUMNS, uidsig_columns));
         g_signal_connect (store, "update-row", G_CALLBACK (names_update_row), swidget);
         
         /* Icon column */
@@ -526,7 +521,7 @@ do_names (SeahorseWidget *swidget)
         g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
         gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget),
                                                      -1, "", renderer,
-                                                     "stock-id", UIDSIG_ICON, NULL);
+                                                     "gicon", UIDSIG_ICON, NULL);
 
         /* The name column */
         gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget), 
@@ -553,9 +548,9 @@ do_names_signals (SeahorseWidget *swidget)
     SeahorseObject *object;
     GtkTreeSelection *selection;
     GtkWidget *widget;
-    
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
-    
+
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
+
     if (seahorse_object_get_usage (object) != SEAHORSE_USAGE_PRIVATE_KEY)
         return;
     widget = seahorse_widget_get_widget (swidget, "names-tree");
@@ -722,9 +717,9 @@ set_photoid_state (SeahorseWidget *swidget, SeahorsePgpKey *pkey)
 	if (pixbuf)
 		gtk_image_set_from_pixbuf (GTK_IMAGE (photo_image), pixbuf);
 	else if (etype == SEAHORSE_USAGE_PRIVATE_KEY)
-		gtk_image_set_from_stock (GTK_IMAGE (photo_image), SEAHORSE_STOCK_SECRET, (GtkIconSize)-1);
+		gtk_image_set_from_icon_name (GTK_IMAGE (photo_image), SEAHORSE_ICON_SECRET, (GtkIconSize)-1);
 	else 
-		gtk_image_set_from_stock (GTK_IMAGE (photo_image), SEAHORSE_STOCK_KEY, (GtkIconSize)-1);
+		gtk_image_set_from_icon_name (GTK_IMAGE (photo_image), SEAHORSE_ICON_KEY, (GtkIconSize)-1);
 }
 
 static void
@@ -825,9 +820,9 @@ enum {
     UID_N_COLUMNS
 };
 
-const GType uid_columns[] = {
+static GType uid_columns[] = {
     G_TYPE_OBJECT,  /* object */
-    G_TYPE_STRING,  /* icon */
+    0 /* later */,  /* icon */
     G_TYPE_STRING,  /* name */
     G_TYPE_STRING,  /* email */
     G_TYPE_STRING   /* comment */
@@ -838,7 +833,7 @@ on_pgp_owner_passphrase_button_clicked (GtkWidget *widget,
                                         gpointer user_data)
 {
 	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
-	SeahorseObject *object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+	SeahorseObject *object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
 	if (seahorse_object_get_usage (object) == SEAHORSE_USAGE_PRIVATE_KEY && 
 	    SEAHORSE_IS_GPGME_KEY (object))
 		seahorse_gpgme_key_op_change_pass (SEAHORSE_GPGME_KEY (object));
@@ -850,8 +845,8 @@ do_owner_signals (SeahorseWidget *swidget)
     SeahorseObject *object;
     SeahorseUsage etype;
     GtkWidget *frame;
-    
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     etype = seahorse_object_get_usage (object);
 
     if (etype == SEAHORSE_USAGE_PRIVATE_KEY ) {
@@ -882,8 +877,9 @@ do_owner (SeahorseWidget *swidget)
 	const gchar *markup;
 	const gchar *label;
 	GList *uids, *l;
+	GIcon *icon;
 
-	object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+	object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
 	pkey = SEAHORSE_PGP_KEY (object);
 
 	flags = seahorse_object_get_flags (object);
@@ -952,7 +948,9 @@ do_owner (SeahorseWidget *swidget)
 			gtk_list_store_clear (GTK_LIST_STORE (store));
             
 		} else {
-    
+			g_assert (UID_N_COLUMNS != G_N_ELEMENTS (uid_columns));
+			uid_columns[1] = G_TYPE_ICON;
+
 			/* This is our first time so create a store */
 			store = gtk_list_store_newv (UID_N_COLUMNS, (GType*)uid_columns);
     
@@ -961,7 +959,7 @@ do_owner (SeahorseWidget *swidget)
 			g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
 			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget),
 			                                             -1, "", renderer,
-			                                             "stock-id", UID_ICON, NULL);
+			                                             "gicon", UID_ICON, NULL);
 
 			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget), 
 			                                             -1, _("Name"), gtk_cell_renderer_text_new (), 
@@ -971,11 +969,13 @@ do_owner (SeahorseWidget *swidget)
 		for (l = uids; l; l = g_list_next (l)) {
     
 			markup = seahorse_object_get_markup (l->data);
+			icon = g_themed_icon_new (SEAHORSE_ICON_PERSON);
 			gtk_list_store_append (store, &iter);
 			gtk_list_store_set (store, &iter,  
 			                    UID_OBJECT, l->data,
-			                    UID_ICON, SEAHORSE_STOCK_PERSON,
+			                    UID_ICON, icon,
 			                    UID_MARKUP, markup, -1);
+			g_object_unref (icon);
 		} 
         
 		gtk_tree_view_set_model (GTK_TREE_VIEW (widget), GTK_TREE_MODEL(store));
@@ -1048,7 +1048,7 @@ on_pgp_details_add_subkey_button (GtkButton *button,
                                   gpointer user_data)
 {
 	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
-	SeahorseObject *object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+	GObject *object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
 	g_return_if_fail (SEAHORSE_IS_GPGME_KEY (object));
 	seahorse_gpgme_add_subkey_new (SEAHORSE_GPGME_KEY (object), GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)));
 }
@@ -1114,8 +1114,8 @@ on_pgp_details_trust_changed (GtkComboBox *selection,
 	set = gtk_combo_box_get_active_iter (selection, &iter);
 	if (!set) 
 		return;
-	
-	object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+
+	object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
 	g_return_if_fail (SEAHORSE_IS_GPGME_KEY (object));
     	
 	model = gtk_combo_box_get_model (selection);
@@ -1151,7 +1151,7 @@ on_pgp_details_export_button (GtkWidget *widget,
                               gpointer user_data)
 {
 	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
-	SeahorseObject *object;
+	GObject *object;
 	GtkDialog *dialog;
 	gchar* uri = NULL;
 	GError *err = NULL;
@@ -1162,7 +1162,7 @@ on_pgp_details_export_button (GtkWidget *widget,
 	gchar *results;
 	gsize n_results;
 	gpgme_key_t seckey;
-    
+
 	object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
 	g_return_if_fail (SEAHORSE_IS_GPGME_KEY (object));
 
@@ -1181,7 +1181,7 @@ on_pgp_details_export_button (GtkWidget *widget,
 	/* Export to a data block */
 	gerr = gpgme_data_new (&data);
 	g_return_if_fail (GPG_IS_OK (gerr));
-	ctx = seahorse_gpgme_source_new_context ();
+	ctx = seahorse_gpgme_keyring_new_context ();
 	g_return_if_fail (ctx);
 	gerr = seahorse_gpg_op_export_secret (ctx, seckey->subkeys->keyid, data);
 	gpgme_release (ctx);
@@ -1252,7 +1252,7 @@ setup_details_trust (SeahorseWidget *swidget)
 
     seahorse_debug ("KeyProperties: Setting up Trust Combo Box Store");
 
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     etype = seahorse_object_get_usage (object);
     
     widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "details-trust-combobox"));
@@ -1311,8 +1311,8 @@ do_details_signals (SeahorseWidget *swidget)
     SeahorseObject *object;
     SeahorseUsage etype;
     GtkWidget *widget;
-    
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     etype = seahorse_object_get_usage (object);
     
     /* 
@@ -1352,17 +1352,14 @@ do_details (SeahorseWidget *swidget)
     const gchar *label;
     gint trust;
     GList *subkeys, *l;
-    guint keyloc;
     gboolean valid;
 
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     pkey = SEAHORSE_PGP_KEY (object);
     
     subkeys = seahorse_pgp_key_get_subkeys (pkey);
     g_return_if_fail (subkeys && subkeys->data);
     subkey = SEAHORSE_PGP_SUBKEY (subkeys->data);
-    
-    keyloc = seahorse_object_get_location (object);
 
     widget = GTK_WIDGET (gtk_builder_get_object (swidget->gtkbuilder, "details-id-label"));
     if (widget) {
@@ -1401,7 +1398,7 @@ do_details (SeahorseWidget *swidget)
     widget = GTK_WIDGET (gtk_builder_get_object (swidget->gtkbuilder, "details-expires-label"));
     if (widget) {
         gulong expires = seahorse_pgp_subkey_get_expires (subkey);
-        if (seahorse_object_get_location (object) == SEAHORSE_LOCATION_REMOTE)
+        if (!SEAHORSE_IS_GPGME_KEY (object))
             fp_label = NULL;
         else if (expires == 0)
             fp_label = g_strdup (C_("Expires", "Never"));
@@ -1411,7 +1408,7 @@ do_details (SeahorseWidget *swidget)
         g_free (fp_label);
     }
 
-    show_gtkbuilder_widget (swidget, "details-trust-combobox", keyloc == SEAHORSE_LOCATION_LOCAL);
+    show_gtkbuilder_widget (swidget, "details-trust-combobox", SEAHORSE_IS_GPGME_KEY (object));
     widget = GTK_WIDGET (gtk_builder_get_object (swidget->gtkbuilder, "details-trust-combobox"));
     
     if (widget) {
@@ -1527,8 +1524,8 @@ enum {
     SIGN_N_COLUMNS
 };
 
-const GType sign_columns[] = {
-    G_TYPE_STRING,
+static GType sign_columns[] = {
+    0 /* later */,
     G_TYPE_STRING,
     G_TYPE_STRING,
     G_TYPE_BOOLEAN
@@ -1551,10 +1548,10 @@ on_pgp_trust_marginal_toggled (GtkToggleButton *toggle,
                                gpointer user_data)
 {
     SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
-    SeahorseObject *object;
+    GObject *object;
     guint trust;
     gpgme_error_t err;
-    
+
     object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
     g_return_if_fail (SEAHORSE_IS_GPGME_KEY (object));
     
@@ -1573,44 +1570,33 @@ static void
 trust_update_row (SeahorseObjectModel *skmodel, SeahorseObject *object, 
                   GtkTreeIter *iter, SeahorseWidget *swidget)
 {
-	SeahorseObject *preferred;
 	gboolean trusted = FALSE;
-	const gchar *icon;
+	GIcon *icon;
 	const gchar *name, *id;
-    
-    	/* Always use the most preferred key for this keyid */
-	preferred = seahorse_object_get_preferred (object);
-	if (SEAHORSE_IS_OBJECT (preferred)) {
-		while (SEAHORSE_IS_OBJECT (preferred)) {
-			object = SEAHORSE_OBJECT (preferred);
-			preferred = seahorse_object_get_preferred (preferred);
-		}
-		seahorse_object_model_set_row_object (skmodel, iter, object);
-	}
-
 
 	if (seahorse_object_get_usage (object) == SEAHORSE_USAGE_PRIVATE_KEY) 
 		trusted = TRUE;
 	else if (seahorse_object_get_flags (object) & SEAHORSE_FLAG_TRUSTED)
 		trusted = TRUE;
-    
-	icon = seahorse_object_get_location (object) < SEAHORSE_LOCATION_LOCAL ? 
-	                GTK_STOCK_DIALOG_QUESTION : SEAHORSE_STOCK_SIGN;
+
+	icon = g_themed_icon_new (SEAHORSE_IS_PGP_KEY (object) ?
+	                               SEAHORSE_ICON_SIGN : GTK_STOCK_DIALOG_QUESTION);
 	name = seahorse_object_get_label (object);
 	id = seahorse_object_get_identifier (object);
-	
+
 	gtk_tree_store_set (GTK_TREE_STORE (skmodel), iter,
 	                    SIGN_ICON, icon,
 	                    SIGN_NAME, name ? name : _("[Unknown]"),
 	                    SIGN_KEYID, id,
 	                    SIGN_TRUSTED, trusted,
-                        -1);
+	                    -1);
+	g_object_unref (icon);
 }
 
 static void
 signatures_populate_model (SeahorseWidget *swidget, SeahorseObjectModel *skmodel)
 {
-	SeahorseObject *object;
+	GObject *object;
 	SeahorsePgpKey *pkey;
 	GtkTreeIter iter;
 	GtkWidget *widget;
@@ -1652,15 +1638,14 @@ signatures_populate_model (SeahorseWidget *swidget, SeahorseObjectModel *skmodel
 		 * search scope together
 		 */
 		cancellable = g_cancellable_new ();
-		keys = seahorse_context_discover_objects (seahorse_context_instance (), SEAHORSE_PGP,
-		                                          rawids, cancellable);
+		keys = seahorse_pgp_backend_discover_keys (NULL, rawids, cancellable);
 		g_object_unref (cancellable);
 		g_list_free (rawids);
 		rawids = NULL;
         
 		/* Add the keys to the store */
 		for (l = keys; l; l = g_list_next (l)) {
-			object = SEAHORSE_OBJECT (l->data);
+			object = G_OBJECT (l->data);
 			gtk_tree_store_append (GTK_TREE_STORE (skmodel), &iter, NULL);
             
 			/* This calls the 'update-row' callback, to set the values for the key */
@@ -1686,7 +1671,7 @@ on_pgp_trust_sign (GtkWidget *widget,
                    gpointer user_data)
 {
 	SeahorseWidget *swidget = SEAHORSE_WIDGET (user_data);
-	SeahorseObject *object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+	GObject *object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
 	g_return_if_fail (SEAHORSE_IS_GPGME_KEY (object));
 	seahorse_gpgme_sign_prompt (SEAHORSE_GPGME_KEY (object), GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)));
 }
@@ -1697,8 +1682,8 @@ do_trust_signals (SeahorseWidget *swidget)
     SeahorseObject *object;
     SeahorseUsage etype;
     const gchar *user;
-    
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     etype = seahorse_object_get_usage (object);
     
     if (etype != SEAHORSE_USAGE_PUBLIC_KEY)
@@ -1761,24 +1746,21 @@ do_trust (SeahorseWidget *swidget)
     GtkTreeModelFilter *filter;
     gboolean sigpersonal;
     GtkCellRenderer *renderer;
-    guint keyloc;
-    
-    object = SEAHORSE_OBJECT_WIDGET (swidget)->object;
+
+    object = SEAHORSE_OBJECT (SEAHORSE_OBJECT_WIDGET (swidget)->object);
     pkey = SEAHORSE_PGP_KEY (object);
-    keyloc = seahorse_object_get_location (object);
-    
+
     if (seahorse_object_get_usage (object) != SEAHORSE_USAGE_PUBLIC_KEY)
         return;
     
     /* Remote keys */
-    if (keyloc < SEAHORSE_LOCATION_LOCAL) {
-        
+    if (!SEAHORSE_IS_GPGME_KEY (object)) {
         show_gtkbuilder_widget (swidget, "manual-trust-area", FALSE);
         show_gtkbuilder_widget (swidget, "manage-trust-area", TRUE);
         show_gtkbuilder_widget (swidget, "sign-area", FALSE);
         show_gtkbuilder_widget (swidget, "revoke-area", FALSE);
         sensitive_gtkbuilder_widget (swidget, "trust-marginal-check", FALSE);
-        set_gtkbuilder_image (swidget, "sign-image", SEAHORSE_STOCK_SIGN_UNKNOWN);
+        set_gtkbuilder_image (swidget, "sign-image", SEAHORSE_ICON_SIGN_UNKNOWN);
         
     /* Local keys */
     } else {
@@ -1800,26 +1782,26 @@ do_trust (SeahorseWidget *swidget)
         /* Trust is specified manually */
         case SEAHORSE_VALIDITY_ULTIMATE:
             managed = FALSE;
-            icon = SEAHORSE_STOCK_SIGN_OK;
+            icon = SEAHORSE_ICON_SIGN_OK;
             break;
         
         /* Trust is specified manually */
         case SEAHORSE_VALIDITY_NEVER:
             managed = FALSE;
-            icon = SEAHORSE_STOCK_SIGN_BAD;
+            icon = SEAHORSE_ICON_SIGN_BAD;
             break;
         
         /* We manage the trust through this page */
         case SEAHORSE_VALIDITY_FULL:
         case SEAHORSE_VALIDITY_MARGINAL:
             managed = TRUE;
-            icon = SEAHORSE_STOCK_SIGN_OK;
+            icon = SEAHORSE_ICON_SIGN_OK;
             break;
         
         /* We manage the trust through this page */
         case SEAHORSE_VALIDITY_UNKNOWN:
             managed = TRUE;
-            icon = SEAHORSE_STOCK_SIGN;
+            icon = SEAHORSE_ICON_SIGN;
             break;
         
         default:
@@ -1867,6 +1849,7 @@ do_trust (SeahorseWidget *swidget)
 		} else {
         
 			/* Create a new SeahorseObjectModel store.... */
+			sign_columns[SIGN_ICON] = G_TYPE_ICON;
 			store = GTK_TREE_STORE (seahorse_object_model_new (SIGN_N_COLUMNS, (GType*)sign_columns));
 			g_signal_connect (store, "update-row", G_CALLBACK (trust_update_row), swidget);
         
@@ -1880,7 +1863,7 @@ do_trust (SeahorseWidget *swidget)
 			g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
 			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget),
 			                                             -1, "", renderer,
-			                                             "stock-id", SIGN_ICON, NULL);
+			                                             "gicon", SIGN_ICON, NULL);
 			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (widget), 
 			                                             -1, _("Name/Email"), gtk_cell_renderer_text_new (), 
 			                                             "text", SIGN_NAME, NULL);
@@ -1893,9 +1876,9 @@ do_trust (SeahorseWidget *swidget)
 			g_signal_connect (widget, "toggled", G_CALLBACK (on_pgp_trusted_toggled), filter);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 		}
-
-		signatures_populate_model (swidget, SEAHORSE_OBJECT_MODEL (store));
 	}
+
+	signatures_populate_model (swidget, SEAHORSE_OBJECT_MODEL (store));
 }
 
 /* -----------------------------------------------------------------------------
@@ -1928,8 +1911,8 @@ setup_public_properties (SeahorsePgpKey *pkey, GtkWindow *parent)
     SeahorseWidget *swidget;
     GtkWidget *widget;
 
-    swidget = seahorse_object_widget_new ("pgp-public-key-properties", parent, SEAHORSE_OBJECT (pkey));    
-    
+    swidget = seahorse_object_widget_new ("pgp-public-key-properties", parent, G_OBJECT (pkey));
+
     /* This happens if the window is already open */
     if (swidget == NULL)
         return NULL;
@@ -1963,7 +1946,7 @@ setup_private_properties (SeahorsePgpKey *pkey, GtkWindow *parent)
     SeahorseWidget *swidget;
     GtkWidget *widget;
 
-    swidget = seahorse_object_widget_new ("pgp-private-key-properties", parent, SEAHORSE_OBJECT (pkey));
+    swidget = seahorse_object_widget_new ("pgp-private-key-properties", parent, G_OBJECT (pkey));
 
     /* This happens if the window is already open */
     if (swidget == NULL)
@@ -1995,28 +1978,16 @@ setup_private_properties (SeahorsePgpKey *pkey, GtkWindow *parent)
 void
 seahorse_pgp_key_properties_show (SeahorsePgpKey *pkey, GtkWindow *parent)
 {
-    SeahorseObject *sobj = SEAHORSE_OBJECT (pkey);
-    SeahorseSource *sksrc;
-    SeahorseWidget *swidget;
+	SeahorseWidget *swidget;
 
-    /* Reload the key to make sure to get all the props */
-    sksrc = seahorse_object_get_source (sobj);
-    g_return_if_fail (sksrc != NULL);
-    
-    /* Don't trigger the import of remote keys if possible */
-    if (SEAHORSE_IS_GPGME_KEY (pkey)) {
-        /* This causes the key source to get any specific info about the key */
-        seahorse_gpgme_key_refresh (SEAHORSE_GPGME_KEY (pkey));
-        seahorse_gpgme_key_ensure_signatures (SEAHORSE_GPGME_KEY (pkey));
-        sobj = seahorse_context_get_object (SCTX_APP(), sksrc, seahorse_object_get_id (sobj));
-        g_return_if_fail (sobj != NULL);
-    }
-    
-    if (seahorse_object_get_usage (sobj) == SEAHORSE_USAGE_PUBLIC_KEY)
-        swidget = setup_public_properties (pkey, parent);
-    else
-        swidget = setup_private_properties (pkey, parent);       
-    
-    if (swidget)
-        seahorse_widget_show (swidget);
+	/* This causes the key source to get any specific info about the key */
+	if (SEAHORSE_IS_GPGME_KEY (pkey))
+		seahorse_gpgme_key_refresh (SEAHORSE_GPGME_KEY (pkey));
+
+	if (seahorse_object_get_usage (SEAHORSE_OBJECT (pkey)) == SEAHORSE_USAGE_PUBLIC_KEY)
+		swidget = setup_public_properties (pkey, parent);
+	else
+		swidget = setup_private_properties (pkey, parent);
+	if (swidget)
+		seahorse_widget_show (swidget);
 }
