@@ -22,21 +22,16 @@
 #ifndef __SEAHORSE_PKCS11_H__
 #define __SEAHORSE_PKCS11_H__
 
+#ifdef WITH_PKCS11
+
 #include <glib.h>
-#include <glib-object.h>
-#include <gp11.h>
-#include <gp11-hacks.h>
 
-G_BEGIN_DECLS
+#include <gcr/gcr.h>
 
+#define SEAHORSE_PKCS11_NAME "pkcs11"
 
+void       seahorse_pkcs11_backend_initialize    (void);
 
-#define SEAHORSE_PKCS11_TYPE_STR "pkcs11"
-#define SEAHORSE_PKCS11_TYPE g_quark_from_string ("pkcs11")
-GQuark seahorse_pkcs11_id_from_attributes (GP11Attributes* attrs);
-gboolean seahorse_pkcs11_id_to_attributes (GQuark id, GP11Attributes* attrs);
-
-
-G_END_DECLS
+#endif /* WITH_PKCS11 */
 
 #endif
