@@ -22,18 +22,20 @@
 #ifndef __SEAHORSE_SSH_H__
 #define __SEAHORSE_SSH_H__
 
+#ifdef WITH_SSH
+
 #include <glib.h>
 #include <glib-object.h>
 
-G_BEGIN_DECLS
+#include <gcr/gcr.h>
 
-
-
-#define SEAHORSE_SSH_TYPE_STR "openssh"
-#define SEAHORSE_SSH_TYPE g_quark_from_string ("openssh")
+#define SEAHORSE_SSH_NAME "openssh"
+#define SEAHORSE_SSH_TYPE_STR SEAHORSE_SSH_NAME
+#define SEAHORSE_SSH (g_quark_from_static_string (SEAHORSE_PGP_NAME))
 #define SEAHORSE_SSH_STOCK_ICON "seahorse-key-ssh"
 
+void       seahorse_ssh_backend_initialize    (void);
 
-G_END_DECLS
+#endif /* WITH_SSH */
 
 #endif
